@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: zzz.R 572 2007-04-15 23:40:50Z dmurdoch $
+## $Id: zzz.R 585 2007-07-17 14:01:23Z dmurdoch $
 ##
 
 ##
@@ -44,7 +44,12 @@
   } 
   
   if ( .Platform$OS.type == "windows" ) {
-    if ( getWindowsHandle("Frame") ) initValue <- getWindowsHandle("Console")
+    frame <- getWindowsHandle("Frame")    
+    ## getWindowsHandle was numeric pre-2.6.0 
+    if ( is.numeric(frame) ) {
+    	if (frame ) initValue <- getWindowsHandle("Console")
+    } else
+    	if ( !is.null(frame) ) initValue <- getWindowsHandle("Console")
   } 
   
   useDynLib <- function(dll, entries) {
@@ -79,10 +84,8 @@
   
 }
 
-rgl.init <- function(initValue = 0) .C( rgl_init, 
-    success=FALSE ,
-    as.integer(initValue)
-  )$success
+rgl.init <- function(initValue = 0) .Call( rgl_init, 
+    initValue )
 
 ##
 ## exit-point
