@@ -130,25 +130,44 @@ FaceSet::FaceSet(
   Material& in_material, 
   int in_nelements, 
   double* in_vertex, 
+  double* in_normals,
+  double* in_texcoords,
   int in_type, 
   int in_nverticesperelement,
-  int in_ignoreExtent
+  int in_ignoreExtent,
+  int in_useNormals,
+  int in_useTexcoords
 
 )
 : PrimitiveSet(in_material, in_nelements, in_vertex, in_type, in_nverticesperelement, in_ignoreExtent)
 {
   if (material.lit) {
     normalArray.alloc(nvertices);
-    for (int i=0;i<=nvertices-nverticesperelement;i+=nverticesperelement) 
-    {   
-      if (hasmissing && (vertexArray[i].missing() ||
-                         vertexArray[i+1].missing() ||
-                         vertexArray[i+2].missing()) )
-        normalArray[i] = Vertex(0.0, 0.0, 0.0);
-      else
-        normalArray[i] = vertexArray.getNormal(i,i+1,i+2);
-      for (int j=1;j<nverticesperelement;++j)    
-        normalArray[i+j] = normalArray[i];
+    if (in_useNormals) {
+      for(int i=0;i<nvertices;i++) {
+        normalArray[i].x = (float) in_normals[i*3+0];
+        normalArray[i].y = (float) in_normals[i*3+1];
+        normalArray[i].z = (float) in_normals[i*3+2];
+      }
+    } else {
+      for (int i=0;i<=nvertices-nverticesperelement;i+=nverticesperelement) 
+      {   
+        if (hasmissing && (vertexArray[i].missing() ||
+                           vertexArray[i+1].missing() ||
+                           vertexArray[i+2].missing()) )
+          normalArray[i] = Vertex(0.0, 0.0, 0.0);
+        else
+          normalArray[i] = vertexArray.getNormal(i,i+1,i+2);
+        for (int j=1;j<nverticesperelement;++j)    
+          normalArray[i+j] = normalArray[i];
+      }
+    }
+  }
+  if (in_useTexcoords) {
+    texCoordArray.alloc(nvertices);
+    for(int i=0;i<nvertices;i++) {
+      texCoordArray[i].s = (float) in_texcoords[i*2+0];
+      texCoordArray[i].t = (float) in_texcoords[i*2+1];      
     }
   }
 }
@@ -162,12 +181,16 @@ void FaceSet::drawBegin(RenderContext* renderContext)
 
   if (material.lit)
     normalArray.beginUse();
+    
+  texCoordArray.beginUse();
 }
 
 // ---------------------------------------------------------------------------
 
 void FaceSet::drawEnd(RenderContext* renderContext)
 {  
+  texCoordArray.endUse();
+  
   if (material.lit)
     normalArray.endUse();
 
